@@ -5,7 +5,7 @@ from datetime import datetime
 from re import fullmatch
 from lxml import etree as ET
 
-from ocrd_utils import is_local_filename, getLogger, VERSION, REGEX_PREFIX
+from ocrd_utils import is_local_filename, getLogger, VERSION, REGEX_PREFIX, REGEX_FILE_ID
 
 from .constants import (
     NAMESPACES as NS,
@@ -20,14 +20,12 @@ from .constants import (
     IDENTIFIER_PRIORITY,
     TAG_MODS_IDENTIFIER,
     METS_XML_EMPTY,
-    REGEX_FILE_ID
 )
 
 from .ocrd_xml_base import OcrdXmlDocument, ET
 from .ocrd_file import OcrdFile
 from .ocrd_agent import OcrdAgent
 
-log = getLogger('ocrd_models.ocrd_mets')
 REGEX_PREFIX_LEN = len(REGEX_PREFIX)
 
 class OcrdMets(OcrdXmlDocument):
@@ -213,6 +211,7 @@ class OcrdMets(OcrdXmlDocument):
             recursive (boolean): Whether to recursively delete all files in the group
             force (boolean): Do not raise an exception if file group doesn't exist
         """
+        log = getLogger('ocrd_models.ocrd_mets.remove_file_group')
         el_fileSec = self._tree.getroot().find('mets:fileSec', NS)
         if el_fileSec is None:
             raise Exception("No fileSec!")
@@ -294,6 +293,7 @@ class OcrdMets(OcrdXmlDocument):
         """
         Delete a `OcrdFile </../../ocrd_models/ocrd_models.ocrd_file.html>`_.
         """
+        log = getLogger('ocrd_models.ocrd_mets.remove_one_file')
         log.info("remove_one_file(%s)" % ID)
         if isinstance(ID, OcrdFile):
             ocrd_file = ID
